@@ -14,5 +14,5 @@ qdq <- function(x, y) {
         stop("Cannot happen!")
     }
 
-    .Call("qoq", x, y, as.integer(4), PACKAGE = "rcdd")
+    .Call(C_qoq, x, y, as.integer(4))
 }
