@@ -15,14 +15,14 @@ scdd <- function(input, adjacency = FALSE, inputadjacency = FALSE,
     validcdd(input, representation)
 
     if (is.character(input)) {
-        out <- .Call("scdd", input, h, roworder, adjacency,
-            inputadjacency, incidence, inputincidence, PACKAGE = "rcdd")
+        out <- .Call(C_scdd, input, h, roworder, adjacency,
+            inputadjacency, incidence, inputincidence)
     } else {
         if (! is.numeric(input))
             stop("input must be numeric or character")
         storage.mode(input) <- "double"
-        out <- .Call("scdd_f", input, h, roworder, adjacency,
-            inputadjacency, incidence, inputincidence, PACKAGE = "rcdd")
+        out <- .Call(C_scdd_f, input, h, roworder, adjacency,
+            inputadjacency, incidence, inputincidence)
     }
 
     attr(out$output, "representation") <- ifelse(! h, "H", "V")
